@@ -33,7 +33,7 @@ import docformatter
 import unify
 
 
-__version__ = '0.1'
+__version__ = '0.1.1'
 
 
 try:
@@ -45,7 +45,8 @@ except NameError:
 FORMATTERS = [
     autoflake.fix_code,
     autopep8.fix_string,
-    docformatter.format_code,
+    lambda code: docformatter.format_code(code,
+                                          summary_wrap_length=79),
     unify.format_code
 ]
 
@@ -88,6 +89,9 @@ def format_file(filename, args, standard_out):
     with open_with_encoding(filename, encoding=encoding) as input_file:
         source = input_file.read()
 
+    if not source:
+        return
+
     formatted_source = format_code(source)
 
     if source != formatted_source:
